==> aliyun-python-sdk-iot-7.11.0.tar.gz: aliyun-python-sdk-iot-7.11.0/aliyunsdkiot/request/v20180120/DeleteTopicRouteTableRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class DeleteTopicRouteTableRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'DeleteTopicRouteTable','iot')

	def get_DstTopics(self):
		return self.get_query_params().get('DstTopics')

	def set_DstTopics(self,DstTopics):
		for i in range(len(DstTopics)):	
			if DstTopics[i] is not None:
				self.add_query_param('DstTopic.' + str(i + 1) , DstTopics[i]);

	def get_IotInstanceId(self):
		return self.get_query_params().get('IotInstanceId')

	def set_IotInstanceId(self,IotInstanceId):
		self.add_query_param('IotInstanceId',IotInstanceId)

	def get_SrcTopic(self):
		return self.get_query_params().get('SrcTopic')

	def set_SrcTopic(self,SrcTopic):
		self.add_query_param('SrcTopic',SrcTopic)

==> aliyun-python-sdk-iot-8.7.0.tar.gz: aliyun-python-sdk-iot-8.7.0/aliyunsdkiot/request/v20180120/DeleteTopicRouteTableRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkiot.endpoint import endpoint_data

class DeleteTopicRouteTableRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'DeleteTopicRouteTable','Iot')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_DstTopics(self):
		return self.get_query_params().get('DstTopics')

	def set_DstTopics(self,DstTopics):
		for i in range(len(DstTopics)):	
			if DstTopics[i] is not None:
				self.add_query_param('DstTopic.' + str(i + 1) , DstTopics[i]);

	def get_IotInstanceId(self):
		return self.get_query_params().get('IotInstanceId')

	def set_IotInstanceId(self,IotInstanceId):
		self.add_query_param('IotInstanceId',IotInstanceId)

	def get_SrcTopic(self):
		return self.get_query_params().get('SrcTopic')

	def set_SrcTopic(self,SrcTopic):
		self.add_query_param('SrcTopic',SrcTopic)
